\name{dev_off_crop}
\alias{dev.off.crop}
\title{Cropping Device}
\description{
  \code{dev.off.crop()} calls \code{\link{dev.off}()} to close the
  plotting device and then crops the produced graphic. This works on
  Unix-like systems if the right underlying Unix tools are installed and
  found (see below).
}
\usage{
dev.off.crop(file = NULL, warn = TRUE, which = dev.cur(),
             post.cmd = "1>/dev/null 2>&1", ...)
}
\arguments{
  \item{file}{output file name including extension (for example
    \code{"Rplots.pdf"} or \code{"outdir/Rplots.pdf"}, where
    \code{outdir} is the base name (without leading \code{./})
    of the output directory).}
  \item{warn}{\code{\link{logical}} indicating whether warnings shall
    be given in case an unsupported operating system is used or the
    underlying Unix tools are not found.}
  \item{which}{see \code{\link{dev.off}()}.}
  \item{post.cmd}{\code{\link{character}} string appended to the main
    underlying commands (\code{epstool}, \code{pdfcrop}, \code{mogrify}).}
  \item{\dots}{additional arguments passed to the underlying \code{\link{system}()}.}
}
\value{
  \code{\link{invisible}()}.
}
\details{
  If the underlying tools (given in parentheses) are installed and found,
  supported file extensions are \code{.eps}
  (\code{epstool}), \code{.pdf} (\code{pdfcrop}) and
  \code{.png} (\code{mogrify}). If they are not
  installed or found or if an unsupported operating system is used,
  \code{dev.off()} is called instead (and thus no cropping is done).

  For debugging, set \code{post.cmd = ""}.
}
\author{Marius Hofert}
\seealso{
  \code{\link{dev.off}()} for closing a device.
}
\examples{
## EPS
setEPS() # or use onefile = FALSE, horizontal = FALSE, paper = "special" in postscript()
postscript(file = (file <- "crop.eps"))
plot(1:10, 10:1, xlab = "x", ylab = "y")
dev.off.crop(file = file)
stopifnot(file.remove("crop.eps")) # clean-up

## PDF
pdf(file = (file <- "crop.pdf"))
plot(1:10, 10:1, xlab = "x", ylab = "y")
dev.off.crop(file = file)
stopifnot(file.remove("crop.pdf")) # clean-up

## PNG with white background
png(filename = (file <- "crop.png"))
plot(1:10, 10:1, xlab = "x", ylab = "y")
dev.off.crop(file = file)
stopifnot(file.remove("crop.png")) # clean-up

## PNG with transparent background
## Not doable by 'mogrify' (only cropped vertically, not horizontally)
if(FALSE) {
    png(filename = (file <- "crop.png"), bg = "transparent")
    plot(1:10, 10:1, xlab = "x", ylab = "y")
    dev.off.crop(file = file)
}
}
\keyword{utilities}
